==> hive-exec-1.1.1-sources.jar: org/apache/hadoop/hive/ql/plan/ptf/WindowTableFunctionDef.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.plan.ptf;

import java.util.List;


public class WindowTableFunctionDef extends PartitionedTableFunctionDef {
  List<WindowFunctionDef> windowFunctions;
  
  int rankLimit = -1;
  int rankLimitFunction;

  public List<WindowFunctionDef> getWindowFunctions() {
    return windowFunctions;
  }
  public void setWindowFunctions(List<WindowFunctionDef> windowFunctions) {
    this.windowFunctions = windowFunctions;
  }
  public int getRankLimit() {
    return rankLimit;
  }
  public void setRankLimit(int rankLimit) {
    this.rankLimit = rankLimit;
  }
  public int getRankLimitFunction() {
    return rankLimitFunction;
  }
  public void setRankLimitFunction(int rankLimitFunction) {
    this.rankLimitFunction = rankLimitFunction;
  }
}

==> hive-exec-2.1.0-sources.jar: org/apache/hadoop/hive/ql/plan/ptf/WindowTableFunctionDef.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.plan.ptf;

import org.apache.hadoop.hive.ql.plan.Explain;

import java.util.List;

@Explain(displayName = "Windowing table definition")
public class WindowTableFunctionDef extends PartitionedTableFunctionDef {
  List<WindowFunctionDef> windowFunctions;
  
  int rankLimit = -1;
  int rankLimitFunction;

  @Explain(displayName = "window functions")
  public List<WindowFunctionDef> getWindowFunctions() {
    return windowFunctions;
  }
  
  public void setWindowFunctions(List<WindowFunctionDef> windowFunctions) {
    this.windowFunctions = windowFunctions;
  }

  public int getRankLimit() {
    return rankLimit;
  }
  public void setRankLimit(int rankLimit) {
    this.rankLimit = rankLimit;
  }
  public int getRankLimitFunction() {
    return rankLimitFunction;
  }
  public void setRankLimitFunction(int rankLimitFunction) {
    this.rankLimitFunction = rankLimitFunction;
  }
}
